@@ -155,28 +155,26 @@ def create_alembic_table():
 
     version_num = '5999269aad30'
 
-    logger.debug('creating alembic_version table with version_num: %s' %
-                 version_num)
-
     from sqlalchemy import Table, Column, Text
 
     table_name = 'alembic_version'
 
-    def do_create():
-        return Table(
+    conn = DBSession.connection()
+    engine = conn.engine
+    if not engine.dialect.has_table(conn, table_name):
+        logger.debug('creating alembic_version table with version_num: %s' %
+                     version_num)
+        table = Table(
             table_name, Base.metadata,
             Column('version_num', Text)
         )
-
-    if table_name not in Base.metadata:
-        table = do_create()
-        engine = DBSession.connection().engine
         Base.metadata.create_all(engine)
         ins = table.insert().values(version_num=version_num)
         DBSession.connection().execute(ins)
         DBSession.commit()
-
-    logger.debug('alembic_version table is created and initialized')
+        logger.debug('alembic_version table is created and initialized')
+    else:
+        logger.debug('alembic_version table is already there!')
 
 
 def __create_admin__():
