@@ -77,9 +77,9 @@ class SimpleEntity(Base):
        attribute can be skipped. For derived classes use the ``__auto_name__``
        class attribute to control auto naming behaviour.
 
-    :param string name: A string or unicode value that holds the name of this
-      entity.  It should not contain any white space at the beginning and at
-      the end of the string. Valid characters are [a-zA-Z0-9\_/S].
+    :param string name: A string value that holds the name of this entity.
+      It should not contain any white space at the beginning and at the end of
+      the string. Valid characters are [a-zA-Z0-9\_/S].
 
       Advanced::
 
@@ -88,10 +88,16 @@ class SimpleEntity(Base):
         Stalker will automatically generate a uuid4 sequence for the name
         attribute.
 
-    :param str description: A string or unicode attribute that holds the
-      description of this entity object, it could be an empty string, and it
-      could not again have white spaces at the beginning and at the end of the
-      string, again any given objects will be converted to strings
+    :param str description: A string attribute that holds the description of
+      this entity object, it could be an empty string, and it could not again
+      have white spaces at the beginning and at the end of the string,
+      again any given objects will be converted to strings
+
+    :param str generic_text: A string attribute that holds any text based
+      information that should be affiliated with this entity, it could be an
+      empty string, and it could not again have white spaces at the beginning
+      and at the end of the string, again any given objects will be converted
+      to strings.
 
     :param created_by: The :class:`.User` who has created
       this object
@@ -121,7 +127,8 @@ class SimpleEntity(Base):
     __auto_name__ = True
     __strictly_typed__ = False
 
-    # TODO: Allow the user to specify the formatting of the name attribute with a formatter function
+    # TODO: Allow the user to specify the formatting of the name attribute with
+    #       a formatter function
     __name_formatter__ = None
 
     __tablename__ = "SimpleEntities"
@@ -178,13 +185,15 @@ class SimpleEntity(Base):
     date_created = Column(
         DateTime,
         default=datetime.datetime.now(),
-        doc="""A :class:`datetime.datetime` instance showing the creation date and time of this object."""
+        doc="""A :class:`datetime.datetime` instance showing the creation date
+        and time of this object."""
     )
 
     date_updated = Column(
         DateTime,
         default=datetime.datetime.now(),
-        doc="""A :class:`datetime.datetime` instance showing the update date and time of this object."""
+        doc="""A :class:`datetime.datetime` instance showing the update date
+        and time of this object."""
         ,
     )
 
@@ -212,13 +221,21 @@ class SimpleEntity(Base):
     generic_data = relationship(
         'SimpleEntity',
         secondary='SimpleEntity_GenericData',
-        primaryjoin='SimpleEntities.c.id==SimpleEntity_GenericData.c.simple_entity_id',
-        secondaryjoin='SimpleEntity_GenericData.c.other_simple_entity_id==SimpleEntities.c.id',
+        primaryjoin='SimpleEntities.c.id=='
+                    'SimpleEntity_GenericData.c.simple_entity_id',
+        secondaryjoin='SimpleEntity_GenericData.c.other_simple_entity_id=='
+                      'SimpleEntities.c.id',
         post_update=True,
         doc='''This attribute can hold any kind of data which exists in SOM.
         '''
     )
 
+    generic_text = Column(
+        "generic_text",
+        Text,
+        doc="""This attribute can hold any text."""
+    )
+
     thumbnail_id = Column(
         'thumbnail_id',
         Integer,
@@ -240,6 +257,7 @@ class SimpleEntity(Base):
             self,
             name=None,
             description="",
+            generic_text="",
             type=None,
             created_by=None,
             updated_by=None,
@@ -268,6 +286,7 @@ class SimpleEntity(Base):
         self.date_updated = date_updated
         self.type = type
         self.thumbnail = thumbnail
+        self.generic_text = generic_text
         self.html_style = html_style
         self.html_class = html_class
         self.__stalker_version__ = stalker.__version__
@@ -288,6 +307,11 @@ class SimpleEntity(Base):
         """
         return not self.__eq__(other)
 
+    def __hash__(self):
+        """the overridden __hash__ method
+        """
+        return hash(self.id) + 2 * hash(self.name) + 3 * hash(self.entity_type)
+
     @validates("description")
     def _validate_description(self, key, description):
         """validates the given description value
@@ -295,13 +319,27 @@ class SimpleEntity(Base):
         if description is None:
             description = ""
 
-        if not isinstance(description, (str, unicode)):
+        if not isinstance(description, str):
             raise TypeError(
                 '%s.description should be an instance of string, not %s' %
                 (self.__class__.__name__, description.__class__.__name__)
             )
         return description
 
+    @validates("generic_text")
+    def _validate_generic_text(self, key, generic_text):
+        """validates the given generic_text value
+        """
+        if generic_text is None:
+            generic_text = ""
+
+        if not isinstance(generic_text, str):
+            raise TypeError(
+                '%s.generic_text should be an instance of string, not %s' %
+                (self.__class__.__name__, generic_text.__class__.__name__)
+            )
+        return generic_text
+
     @validates("name")
     def _validate_name(self, key, name):
         """validates the given name_in value
@@ -309,8 +347,8 @@ class SimpleEntity(Base):
         if self.__auto_name__:
             if name is None or name == '':
                 # generate a uuid4
-                name = self.__class__.__name__ + '_' + \
-                       uuid.uuid4().urn.split(':')[2]
+                name = '%s_%s' % (self.__class__.__name__,
+                                  uuid.uuid4().urn.split(':')[2])
 
         # it is None
         if name is None:
@@ -318,9 +356,9 @@ class SimpleEntity(Base):
                 "%s.name can not be None" % self.__class__.__name__
             )
 
-        if not isinstance(name, (str, unicode)):
+        if not isinstance(name, str):
             raise TypeError(
-                "%s.name should be an instance of string or unicode not %s" %
+                "%s.name should be an instance of string not %s" %
                 (self.__class__.__name__, name.__class__.__name__)
             )
 
@@ -337,7 +375,8 @@ class SimpleEntity(Base):
 
         return name
 
-    def _format_name(self, name_in):
+    @classmethod
+    def _format_name(cls, name_in):
         """formats the name_in value
         """
         # remove unnecessary characters from the string
@@ -348,7 +387,8 @@ class SimpleEntity(Base):
 
         return name_in
 
-    def _format_nice_name(self, nice_name_in):
+    @classmethod
+    def _format_nice_name(cls, nice_name_in):
         """formats the given nice name
         """
         # remove unnecessary characters from the string
@@ -516,7 +556,7 @@ class SimpleEntity(Base):
         """
         if html_style is None:
             html_style = ''
-        if not isinstance(html_style, basestring):
+        if not isinstance(html_style, str):
             raise TypeError(
                 '%s.html_style should be an instance of basestring, not %s' %
                 (self.__class__.__name__, html_style.__class__.__name__)
@@ -529,7 +569,7 @@ class SimpleEntity(Base):
         """
         if html_class is None:
             html_class = ''
-        if not isinstance(html_class, basestring):
+        if not isinstance(html_class, str):
             raise TypeError(
                 '%s.html_class should be an instance of basestring, not %s' %
                 (self.__class__.__name__, html_class.__class__.__name__)
@@ -626,8 +666,13 @@ class Entity(SimpleEntity):
     def __eq__(self, other):
         """the equality operator
         """
-        return super(Entity, self).__eq__(other) and \
-               isinstance(other, Entity)
+        return super(Entity, self).__eq__(other) \
+            and isinstance(other, Entity)
+
+    def __hash__(self):
+        """the overridden __hash__ method
+        """
+        return hash(self.id) + 2 * hash(self.name) + 3 * hash(self.entity_type)
 
 # Entity Tags
 Entity_Tags = Table(
