@@ -88,3 +88,8 @@ class Sequence(Task, CodeMixin):
         """
         return isinstance(other, Sequence) and \
             super(Sequence, self).__eq__(other)
+
+    def __hash__(self):
+        """the overridden __hash__ method
+        """
+        return hash(self.id) + 2 * hash(self.name) + 3 * hash(self.entity_type)
