@@ -41,12 +41,12 @@ class Status(Entity, CodeMixin):
     No extra parameters, use the *code* attribute to give a short name for the
     status.
 
-    A Status object can be compared with a string or unicode value and it will
-    return if the lower case name or lower case code of the status matches the
-    lower case form of the given string::
+    A Status object can be compared with a string value and it will return if
+    the lower case name or lower case code of the status matches the lower case
+    form of the given string::
 
       >>> from stalker import Status
-      >>> a_status = Status(name="On Hold", "OH")
+      >>> a_status = Status(name="On Hold", code="OH")
       >>> a_status == "on hold"
       True
       >>> a_status != "complete"
@@ -84,13 +84,18 @@ class Status(Entity, CodeMixin):
     def __eq__(self, other):
         """the equality operator
         """
-        if isinstance(other, (str, unicode)):
+        if isinstance(other, str):
             return self.name.lower() == other.lower() or \
                 self.code.lower() == other.lower()
         else:
             return super(Status, self).__eq__(other) and \
                 isinstance(other, Status)
 
+    def __hash__(self):
+        """the overridden __hash__ method
+        """
+        return hash(self.id) + 2 * hash(self.name) + 3 * hash(self.entity_type)
+
 
 class StatusList(Entity, TargetEntityTypeMixin):
     """Type specific list of :class:`.Status` instances.
@@ -177,7 +182,7 @@ class StatusList(Entity, TargetEntityTypeMixin):
     statuses = relationship(
         "Status",
         secondary="StatusList_Statuses",
-        doc="""list of :class:`.Status` objects, showing the possible statuses"""
+        doc="List of :class:`.Status` objects, showing the possible statuses"
     )
 
     def __init__(self, statuses=None, target_entity_type=None, **kwargs):
@@ -208,12 +213,17 @@ class StatusList(Entity, TargetEntityTypeMixin):
             self.statuses == other.statuses and \
             self.target_entity_type == other.target_entity_type
 
+    def __hash__(self):
+        """the overridden __hash__ method
+        """
+        return hash(self.id) + 2 * hash(self.name) + 3 * hash(self.entity_type)
+
     def __getitem__(self, key):
         """the indexing attributes for getting item
         """
         with DBSession.no_autoflush:
             return_item = None
-            if isinstance(key, (str, unicode)):
+            if isinstance(key, str):
                 for item in self.statuses:
                     if item == key:
                         return_item = item
@@ -238,7 +248,7 @@ class StatusList(Entity, TargetEntityTypeMixin):
         return len(self.statuses)
 
 
-# Statuslist_Statuses Table
+# StatusList_Statuses Table
 StatusList_Statuses = Table(
     "StatusList_Statuses", Base.metadata,
     Column(
@@ -254,4 +264,3 @@ StatusList_Statuses = Table(
         primary_key=True
     )
 )
-
