@@ -362,14 +362,14 @@ class Studio(Entity, DateRangeMixin, WorkingHoursMixin):
         """returns all the active projects in the studio
         """
         from stalker import Project
-        return Project.query.filter(Project.active==True).all()
+        return Project.query.filter_by(active=True).all()
 
     @property
     def inactive_projects(self):
         """return all the inactive projects in the studio
         """
         from stalker import Project
-        return Project.query.filter(Project.active==False).all()
+        return Project.query.filter_by(active=False).all()
 
     @property
     def departments(self):
@@ -590,11 +590,16 @@ class WorkingHours(object):
         self.daily_working_hours = daily_working_hours
 
     def __eq__(self, other):
-        """equality test
+        """overridden equality operator
         """
         return isinstance(other, WorkingHours) and \
             other.working_hours == self.working_hours
 
+    def __hash__(self):
+        """the overridden __hash__ method
+        """
+        return hash(self.working_hours)
+
     def __getitem__(self, item):
         if isinstance(item, int):
             return self._wh[defaults.day_order[item]]
