@@ -44,7 +44,9 @@ class FilenameTemplate(Entity, TargetEntityTypeMixin):
     Here is an example::
 
         p1 = Project(name="Test Project") # shortened for this example
-        s1 = Structure(name="Commercial Project Structure") # shortened for this example
+
+        # shortened for this example
+        s1 = Structure(name="Commercial Project Structure")
 
         # this is going to be used by Stalker to decide the :stalker:`.Link`
         # :stalker:`.Link.filename` and :stalker:`.Link.path` (which is the way
@@ -127,9 +129,9 @@ class FilenameTemplate(Entity, TargetEntityTypeMixin):
         if path_in is None:
             path_in = ""
 
-        if not isinstance(path_in, (str, unicode)):
+        if not isinstance(path_in, str):
             raise TypeError(
-                "%s.path attribute should be string or unicode not %s" %
+                "%s.path attribute should be string not %s" %
                 (self.__class__.__name__, path_in.__class__.__name__)
             )
 
@@ -143,9 +145,9 @@ class FilenameTemplate(Entity, TargetEntityTypeMixin):
         if filename_in is None:
             filename_in = ""
 
-        if not isinstance(filename_in, (str, unicode)):
+        if not isinstance(filename_in, str):
             raise TypeError(
-                "%s.filename attribute should be string or unicode not %s" %
+                "%s.filename attribute should be string not %s" %
                 (self.__class__.__name__, filename_in.__class__.__name__)
             )
 
@@ -159,3 +161,8 @@ class FilenameTemplate(Entity, TargetEntityTypeMixin):
             self.target_entity_type == other.target_entity_type and \
             self.path == other.path and \
             self.filename == other.filename
+
+    def __hash__(self):
+        """the overridden __hash__ method
+        """
+        return hash(self.id) + 2 * hash(self.name) + 3 * hash(self.entity_type)
