@@ -22,8 +22,7 @@ import os
 import re
 import jinja2
 
-from sqlalchemy import (Table, Column, Integer, ForeignKey, String, Boolean,
-                        event)
+from sqlalchemy import Table, Column, Integer, ForeignKey, String, Boolean
 from sqlalchemy.exc import UnboundExecutionError
 from sqlalchemy.orm import relationship, validates
 
@@ -192,34 +191,32 @@ class Version(Link):
         """the representation of the Version
         """
         return "<%(project_code)s_%(nice_name)s_%(version_number)s " \
-               "(%(entity_type)s)>" % {
-            'project_code': self.task.project.code,
-            'nice_name': self.nice_name,
-            'version_number': 'v%s' % ('%s' % self.version_number).zfill(3),
-            'entity_type': self.entity_type}
+               "(%(entity_type)s)>" % \
+               {
+                   'project_code': self.task.project.code,
+                   'nice_name': self.nice_name,
+                   'version_number':
+                   'v%s' % ('%s' % self.version_number).zfill(3),
+                   'entity_type': self.entity_type
+               }
 
-    def _format_take_name(self, take_name):
+    @classmethod
+    def _format_take_name(cls, take_name):
         """formats the given take_name value
         """
-        logger.debug("-------------------------------------")
-        logger.debug("take_name : %s" % take_name)
-
         # remove unnecessary characters
         take_name = re.sub(
             r"([^a-zA-Z0-9\s_\-]+)", r"", take_name
         ).strip()
-        logger.debug("take_name : %s" % take_name)
 
         # replace empty spaces with underscores
         take_name = re.sub(r'[\s]+', '_', take_name)
-        logger.debug("take_name : %s" % take_name)
 
         # replace multiple underscores with only one
-        take_name = re.sub(r'([_]+)', r'_', take_name)
-        logger.debug("take_name : %s" % take_name)
+        # take_name = re.sub(r'([_]+)', r'_', take_name)
 
+        # remove any non allowed characters from the start
         take_name = re.sub(r"^[^a-zA-Z0-9]+", r"", take_name)
-        logger.debug("take_name : %s" % take_name)
 
         return take_name
 
@@ -328,19 +325,19 @@ class Version(Link):
         return task
 
     @validates("inputs")
-    def _validate_inputs(self, key, input):
-        """validates the given output
+    def _validate_inputs(self, key, input_):
+        """validates the given input value
         """
         from stalker.models.link import Link
 
-        if not isinstance(input, Link):
+        if not isinstance(input_, Link):
             raise TypeError(
                 "All elements in %s.inputs should be all "
                 "stalker.models.link.Link instances not %s" %
-                (self.__class__.__name__, input.__class__.__name__)
+                (self.__class__.__name__, input_.__class__.__name__)
             )
 
-        return input
+        return input_
 
     @validates("outputs")
     def _validate_outputs(self, key, output):
@@ -396,7 +393,6 @@ class Version(Link):
         if isinstance(self.task, Shot):
             sequences = self.task.sequences
             scenes = self.task.scenes
-            shot = self.task
 
         # get the parent tasks
         task = self.task
@@ -449,9 +445,28 @@ class Version(Link):
                 }
             )
 
-        self.filename = \
+        temp_filename = \
             jinja2.Template(vers_template.filename).render(**kwargs)
-        self.path = jinja2.Template(vers_template.path).render(**kwargs)
+
+        if not isinstance(temp_filename, str):
+            # it is
+            # byte for python3
+            # or
+            # unicode for python2
+            temp_filename = temp_filename.encode('utf-8')
+
+        temp_path = \
+            jinja2.Template(vers_template.path).render(**kwargs)
+
+        if not isinstance(temp_path, str):
+            # it is
+            # byte for python3
+            # or
+            # unicode for python2
+            temp_path = temp_path.encode('utf-8')
+
+        self.filename = temp_filename
+        self.path = temp_path
 
     @property
     def absolute_full_path(self):
@@ -497,11 +512,11 @@ class Version(Link):
 
         :return: :class:`.Version`
         """
-        return Version.query \
-            .filter(Version.task == self.task) \
-            .filter(Version.take_name == self.take_name) \
-            .filter(Version.is_published == True) \
-            .order_by(Version.version_number.desc()) \
+        return Version.query\
+            .filter_by(task=self.task)\
+            .filter_by(take_name=self.take_name)\
+            .filter_by(is_published=True)\
+            .order_by(Version.version_number.desc())\
             .first()
 
     @validates('created_with')
@@ -509,10 +524,9 @@ class Version(Link):
         """validates the given created_with value
         """
         if created_with is not None:
-            if not isinstance(created_with, (str, unicode)):
+            if not isinstance(created_with, str):
                 raise TypeError(
-                    '%s.created_with should be an instance of str or unicode, '
-                    'not %s' %
+                    '%s.created_with should be an instance of str, not %s' %
                     (self.__class__.__name__, created_with.__class__.__name__)
                 )
         return created_with
@@ -526,6 +540,11 @@ class Version(Link):
             self.take_name == other.take_name and \
             self.version_number == other.version_number
 
+    def __hash__(self):
+        """the overridden __hash__ method
+        """
+        return hash(self.id) + 2 * hash(self.name) + 3 * hash(self.entity_type)
+
     @property
     def naming_parents(self):
         """returns a list of parents which start from the nearest Asset, Shot
